#!/bin/sh

sudo apt-get install -y \
    curl \
    gawk \
    libcapture-tiny-perl \
    libcarp-assert-perl \
    libclone-perl \
    libdate-calc-perl \
    libdatetime-format-rfc3339-perl \
    libdbd-mysql-perl \
    libdbd-sqlite3-perl \
    libdbi-perl \
    libdigest-sha-perl \
    libhtml-parser-perl \
    libjson-perl \
    liblist-moreutils-perl \
    libchemistry-openbabel-perl \
    libparse-yapp-perl \
    libwww-curl-perl \
    libxml-simple-perl \
    openbabel \
    perl \
    python-argparse \
    tree \
;
